@@ -4,6 +4,7 @@ import csv
 import zlib
 import json
 import boto3
+import pystow
 import logging
 import argparse
 import requests
@@ -20,16 +21,12 @@ logger = logging.getLogger('protmapper.resources')
 logger.setLevel(logging.INFO)
 
 
-# If the protmapper resource directory does not exist, try to create it
-home_dir = os.path.expanduser('~')
-resource_dir = os.path.join(home_dir, '.protmapper', __version__)
-
-
-if not os.path.isdir(resource_dir):
-    try:
-        os.makedirs(resource_dir)
-    except Exception:
-        logger.warning(resource_dir + ' already exists')
+# If the protmapper resource directory does not exist, try to create it using PyStow
+# Can be specified with PROTMAPPER_HOME environment variable, otherwise defaults
+# to $HOME/.data/protmapper/<__version__>. The location of $HOME can be overridden with
+# the PYSTOW_HOME environment variable
+resource_dir_path = pystow.join('protmapper', __version__)
+resource_dir = resource_dir_path.as_posix()
 
 
 def _download_from_s3(key, out_file):
@@ -73,7 +70,7 @@ def download_uniprot_entries(out_file, cached=True):
         return
     base_columns = ['id', 'genes(PREFERRED)', 'entry%20name',
                     'database(RGD)', 'database(MGI)', 'length', 'reviewed',
-                    'organism-id']
+                    'organism-id', 'database(GeneID)']
     processed_columns = ['genes', 'protein%20names']
     feature_types = ['SIGNAL', 'CHAIN', 'PROPEPTIDE', 'PEPTIDE', 'TRANSIT']
     columns = base_columns + processed_columns + \
@@ -132,9 +129,9 @@ def process_uniprot_line(line, base_columns, processed_columns,
     gene_names_preferred = terms[1].split(';')
     gene_name = gene_names_preferred[0]
     if not gene_name:
-        gene_name = terms[8].split(' ')[0]
+        gene_name = terms[len(base_columns)].split(' ')[0]
 
-    protein_names = parse_uniprot_synonyms(terms[9])
+    protein_names = parse_uniprot_synonyms(terms[len(base_columns)+1])
     protein_name = protein_names[0] if protein_names else None
 
     if gene_name:
@@ -144,6 +141,10 @@ def process_uniprot_line(line, base_columns, processed_columns,
     else:
         terms[1] = None
 
+    # We only add Entrez IDs for reviewed entries to avoid the problem
+    # caused by one-to-many mappings with lots of unreviewed proteins
+    terms[8] = '' if terms[6] != 'reviewed' else terms[8]
+
     # Next we process the various features into a form that can be
     # loaded easily in the client
     features = []
@@ -283,7 +284,7 @@ def download_uniprot_sec_ac(out_file, cached=True):
 
     logger.info('Downloading UniProt secondary accession mappings')
     url = 'ftp://ftp.uniprot.org/pub/databases/uniprot/knowledgebase/' + \
-        'docs/sec_ac.txt'
+        'complete/docs/sec_ac.txt'
     urlretrieve(url, out_file)
 
 
@@ -391,7 +392,7 @@ class ResourceManager(object):
         str
             The path to the resource file.
         """
-        return os.path.join(resource_dir, self.resource_map[resource_id][0])
+        return os.path.join(resource_dir_path, self.resource_map[resource_id][0])
 
     def get_download_fun(self, resource_id):
         """Return the download function for the given resource.
