@@ -593,34 +593,34 @@ def get_hgnc_id(protein_id):
 
 
 def get_entrez_id(protein_id):
-    """Return the Entrez ID given the protein id of a human protein.
+    """Return the Entrez ID given a protein ID.
 
     Parameters
     ----------
     protein_id : str
-        UniProt ID of the human protein
+        UniProt ID of the protein
 
     Returns
     -------
     str or None
-        Entrez ID of the human gene or None if not available.
+        Entrez ID of the corresponding gene or None if not available.
     """
     protein_id = get_primary_id(_strip_isoform(protein_id))
     return um.uniprot_entrez.get(protein_id)
 
 
 def get_id_from_entrez(entrez_id):
-    """Return the uniProt ID given the Entrez ID of a human gene.
+    """Return the UniProt ID given the Entrez ID of a gene.
 
     Parameters
     ----------
     entrez_id : str
-        Entrez ID of the human gene
+        Entrez ID of the gene
 
     Returns
     -------
     str or None
-        UniProt ID of the human protein or None if not available.
+        UniProt ID of the corresponding protein or None if not available.
     """
     return um.entrez_uniprot.get(entrez_id)
 
@@ -967,6 +967,8 @@ class UniprotMapper(object):
         self.initialized_seq = False
         self.initialized_hgnc = False
         self.initialized_refseq = False
+        self._entrez_uniprot = {}
+        self._uniprot_entrez = {}
 
     def initialize(self):
         maps = _build_uniprot_entries()
@@ -975,7 +977,16 @@ class UniprotMapper(object):
          self._uniprot_rgd, self._uniprot_mgi_reverse,
          self._uniprot_rgd_reverse, self._uniprot_length,
          self._uniprot_reviewed, self._features, self._features_by_id,
-         self._organisms_by_id) = maps
+         self._organisms_by_id, _uniprot_entrez,
+         _entrez_uniprot) = maps
+
+        # Here we don't overwrite the value to de-prioritize
+        for k, v in _uniprot_entrez.items():
+            if k not in self._uniprot_entrez:
+                self._uniprot_entrez[k] = v
+        for k, v in _entrez_uniprot.items():
+            if k not in self._entrez_uniprot:
+                self._entrez_uniprot[k] = v
 
         self._uniprot_sec = _build_uniprot_sec()
 
@@ -984,8 +995,17 @@ class UniprotMapper(object):
     def initialize_hgnc(self):
         self._uniprot_human_mouse, self._uniprot_human_rat = \
             _build_human_mouse_rat()
-        _, _, self._uniprot_hgnc, self._entrez_uniprot, \
-            self._uniprot_entrez = _build_hgnc_mappings()
+        _, _, self._uniprot_hgnc, _entrez_uniprot, \
+            _uniprot_entrez = _build_hgnc_mappings()
+
+        # Here we always overwrite the value to prioritize
+        for upid, egid in _uniprot_entrez.items():
+            for uid in upid.split(', '):
+                self._uniprot_entrez[uid] = egid
+        for egid, upid in _entrez_uniprot.items():
+            if ',' not in upid:
+                self._entrez_uniprot[egid] = upid
+
         self.initialized_hgnc = True
 
     def initialize_seq(self):
@@ -1010,12 +1030,16 @@ class UniprotMapper(object):
 
     @property
     def uniprot_entrez(self):
+        if not self.initialized:
+            self.initialize()
         if not self.initialized_hgnc:
             self.initialize_hgnc()
         return self._uniprot_entrez
 
     @property
     def entrez_uniprot(self):
+        if not self.initialized:
+            self.initialize()
         if not self.initialized_hgnc:
             self.initialize_hgnc()
         return self._entrez_uniprot
@@ -1117,6 +1141,7 @@ class UniprotMapper(object):
         return self._organisms_by_id
 
 
+
 um = UniprotMapper()
 
 
@@ -1133,6 +1158,8 @@ def _build_uniprot_entries():
     uniprot_features = {}
     uniprot_reviewed = set()
     organisms_by_id = {}
+    uniprot_entrez = {}
+    uniprot_entrez_reverse = {}
     files = [up_entries_file]
     for file in files:
         with open(file, 'r') as fh:
@@ -1141,7 +1168,7 @@ def _build_uniprot_entries():
             next(csv_rows)
             for row in csv_rows:
                 up_id, gene_name, up_mnemonic, rgd, mgi, length, reviewed, \
-                    organism_id, features_json = row
+                    organism_id, entrez_id, features_json = row
                 # Store the entry in the reviewed set
                 if reviewed == 'reviewed':
                     uniprot_reviewed.add(up_id)
@@ -1164,6 +1191,13 @@ def _build_uniprot_entries():
                                            feat in json.loads(features_json)]
                 organisms_by_id[up_id] = organism_id
 
+                # Entrez mappings
+                entrez_ids = [ei for ei in
+                              [e.strip() for e in entrez_id.split(';')] if ei]
+                for eid in entrez_ids:
+                    uniprot_entrez[up_id] = eid
+                    uniprot_entrez_reverse[eid] = up_id
+
     # Build a dict of features by feature ID
     features_by_id = {}
     for up_id, feats in uniprot_features.items():
@@ -1173,7 +1207,7 @@ def _build_uniprot_entries():
     return (uniprot_gene_name, uniprot_mnemonic, uniprot_mnemonic_reverse,
             uniprot_mgi, uniprot_rgd, uniprot_mgi_reverse, uniprot_rgd_reverse,
             uniprot_length, uniprot_reviewed, uniprot_features, features_by_id,
-            organisms_by_id)
+            organisms_by_id, uniprot_entrez, uniprot_entrez_reverse)
 
 
 def _build_human_mouse_rat():
